@@ -5,6 +5,8 @@ from llama_index.readers.web.async_web.base import (
 from llama_index.readers.web.beautiful_soup_web.base import (
     BeautifulSoupWebReader,
 )
+from llama_index.readers.web.browserbase_web.base import BrowserbaseWebReader
+from llama_index.readers.web.firecrawl_web.base import FireCrawlWebReader
 from llama_index.readers.web.knowledge_base.base import (
     KnowledgeBaseWebReader,
 )
@@ -21,12 +23,18 @@ from llama_index.readers.web.rss.base import (
 from llama_index.readers.web.rss_news.base import (
     RssNewsReader,
 )
+from llama_index.readers.web.scrapfly_web.base import (
+    ScrapflyReader,
+)
 from llama_index.readers.web.simple_web.base import (
     SimpleWebPageReader,
 )
 from llama_index.readers.web.sitemap.base import (
     SitemapReader,
 )
+from llama_index.readers.web.spider_web.base import (
+    SpiderWebReader,
+)
 from llama_index.readers.web.trafilatura_web.base import (
     TrafilaturaWebReader,
 )
@@ -37,17 +45,22 @@ from llama_index.readers.web.whole_site.base import (
     WholeSiteReader,
 )
 
+
 __all__ = [
     "AsyncWebPageReader",
     "BeautifulSoupWebReader",
+    "BrowserbaseWebReader",
+    "FireCrawlWebReader",
     "KnowledgeBaseWebReader",
     "MainContentExtractorReader",
     "NewsArticleReader",
     "ReadabilityWebPageReader",
     "RssReader",
     "RssNewsReader",
+    "ScrapflyReader",
     "SimpleWebPageReader",
     "SitemapReader",
+    "SpiderWebReader",
     "TrafilaturaWebReader",
     "UnstructuredURLLoader",
     "WholeSiteReader",
