@@ -2,40 +2,23 @@
 
 from typing import List
 
-from llama_index.core.readers.base import BaseReader
+from llama_index.core.readers.base import BasePydanticReader
 from llama_index.core.schema import Document
 
 
-class RssReader(BaseReader):
+class RssReader(BasePydanticReader):
     """RSS reader.
 
     Reads content from an RSS feed.
 
     """
 
-    def __init__(self, html_to_text: bool = False) -> None:
-        """Initialize with parameters.
+    is_remote: bool = True
+    html_to_text: bool = False
 
-        Args:
-            html_to_text (bool): Whether to convert HTML to text.
-                Requires `html2text` package.
-
-        """
-        try:
-            import feedparser  # noqa: F401
-        except ImportError:
-            raise ValueError(
-                "`feedparser` package not found, please run `pip install feedparser`"
-            )
-
-        if html_to_text:
-            try:
-                import html2text  # noqa: F401
-            except ImportError:
-                raise ValueError(
-                    "`html2text` package not found, please run `pip install html2text`"
-                )
-        self._html_to_text = html_to_text
+    @classmethod
+    def class_name(cls) -> str:
+        return "RssReader"
 
     def load_data(self, urls: List[str]) -> List[Document]:
         """Load data from RSS feeds.
@@ -57,17 +40,18 @@ class RssReader(BaseReader):
         for url in urls:
             parsed = feedparser.parse(url)
             for entry in parsed.entries:
+                doc_id = entry.id or entry.link
                 if "content" in entry:
                     data = entry.content[0].value
                 else:
                     data = entry.description or entry.summary
 
-                if self._html_to_text:
+                if self.html_to_text:
                     import html2text
 
                     data = html2text.html2text(data)
 
                 extra_info = {"title": entry.title, "link": entry.link}
-                documents.append(Document(text=data, extra_info=extra_info))
+                documents.append(Document(text=data, id_=doc_id, extra_info=extra_info))
 
         return documents
